Package: PupilPre
Type: Package
Title: Preprocessing Pupil Size Data
Version: 0.6.3
Date: 2025-12-19
Authors@R: c(person("Aki-Juhani", "Kyröläinen", role = c("aut", "cre"),
		     email = "akkyro@gmail.com"),
	      person("Vincent", "Porretta", role = "aut"),
	      person("Jacolien", "van Rij", role = "ctb"),
		  person("Juhani", "Järvikivi", role = "ctb"))
Author: Aki-Juhani Kyröläinen [aut, cre],
  Vincent Porretta [aut],
  Jacolien van Rij [ctb],
  Juhani Järvikivi [ctb]
Maintainer: Aki-Juhani Kyröläinen <akkyro@gmail.com>
Description: Pupillometric data collected using SR Research Eyelink eye trackers 
    requires significant preprocessing. This package contains functions for 
    preparing pupil dilation data for visualization and statistical analysis. 
    Specifically, it provides a pipeline of functions which aid in data validation,
    the removal of blinks/artifacts, downsampling, and baselining, among others. 
    Additionally, plotting functions for creating grand average and conditional 
    average plots are provided. See the vignette for samples of the functionality.
    The package is designed for handling data collected with SR Research 
    Eyelink eye trackers using Sample Reports created in SR Research Data 
    Viewer. 
Depends: R (>= 3.5.0), dplyr (>= 0.8.0), rlang (>= 0.1.1), VWPre (>=
        1.2.0)
Imports: ggplot2 (>= 2.2.0), mgcv (>= 1.8-16), shiny (>= 0.14.2), tidyr
        (>= 0.6.0), stats (>= 3.3.2), robustbase (>= 0.93-3), zoo (>=
        1.8-4), signal (>= 0.7-6)
License: GPL-3
LazyData: true
Suggests: knitr, rmarkdown, gridExtra
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2025-12-20 01:07:46 UTC; vjp
Repository: CRAN
Date/Publication: 2025-12-20 14:50:07 UTC
Built: R 4.6.0; ; 2026-04-30 15:27:51 UTC; unix
