# Generated by roxygen2: do not edit by hand

export(NA_summary)
export(apply_butter)
export(apply_cleanup_change)
export(apply_user_cleanup)
export(baseline)
export(blink_summary)
export(butter_filter_app)
export(check_baseline)
export(clean_artifact)
export(clean_blink)
export(compare_summary)
export(downsample)
export(interpolate_NAs)
export(plot_compare_app)
export(plot_events)
export(plot_summary_app)
export(ppl_check_eye_recording)
export(ppl_plot_avg)
export(ppl_plot_avg_cdiff)
export(ppl_plot_avg_contour)
export(ppl_prep_data)
export(ppl_rm_extra_DVcols)
export(ppl_select_recorded_eye)
export(recode_off_screen)
export(rm_sparse_events)
export(trim_filtered)
export(user_cleanup_app)
export(verify_cleanup_app)
import(VWPre)
import(dplyr)
import(ggplot2)
import(rlang)
import(shiny)
import(tidyr)
importFrom(robustbase,covMcd)
importFrom(signal,butter)
importFrom(signal,filtfilt)
importFrom(stats,quantile)
importFrom(stats,relevel)
importFrom(zoo,na.approx)
importFrom(zoo,na.spline)
